#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.41
visibility:           public
id:                   glirc-2.41-HEMdqRb2l1R5Z42hrJRZrA
key:                  glirc-2.41-HEMdqRb2l1R5Z42hrJRZrA
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  2c68bab912c910506c750624ff91dc0b
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec Client.Commands.Help
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Focus Client.Image.Layout
    Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Help Client.State.Network
    Client.State.Target Client.State.Url Client.State.Window
    Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.IgnoreList Client.View.KeyMap
    Client.View.MaskList Client.View.Mentions Client.View.Messages
    Client.View.Palette Client.View.RtsStats Client.View.UrlSelection
    Client.View.UserList Client.View.Who Client.View.WindowSwitch
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.41-HEMdqRb2l1R5Z42hrJRZrA
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.41/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.10-8CEUdRQDZXw2C4QNN7DtRX
    async-2.2.6-JvoT9znxQt2BsREADqk9DD
    attoparsec-0.14.4-GluE1clWXeWeSjHE1bFts base-4.18.2.1
    base64-bytestring-1.2.1.0-6ahp7SfFZkd6mBBNURIRpE
    bytestring-0.11.5.3 config-schema-1.3.0.0-Dzbc0UUEAXqD3CqVrYozjv
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-gQSTv8BGmnLbiblEP46fG directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-Dh7NpJ39NfO9sVJ19HaAmZ
    githash-0.1.7.0-2ROuo1OF70xHbYEhs0VwUI
    hashable-1.4.7.0-8kdP0hepiCNIVGgwFVweHE
    hookup-0.8-4K7cJYHjGbpFkVRXfuN1Cd
    irc-core-2.13-FwPkICKt5RVIeWKGPUhhBQ
    kan-extensions-5.2.8-KA8xyHDLHZi62Mxe17VpPE
    lens-5.3.4-AIhP2tgqTtI4periiO8TOY
    network-3.1.4.0-Lt0aE8CPrcjIQCbzsjcySE
    psqueues-0.2.8.3-L1TQDPv6aOV9RuMs3JNrln
    random-1.2.1.3-Lghf55MzNhHBpx4j4jRaDh
    regex-tdfa-1.3.2.5-AvdfaJ7YsJ1IGV7skEbGGt
    semigroupoids-6.0.2-EfRCiqpKxJiDFKScbpfggs
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-JwtnSlUYcBgBMap6wx0Lr9
    unix-2.8.4.0 unordered-containers-0.2.20.1-owJOmMRhDW8XCXGWMsAkD
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2
    vty-6.2-GFrkwL9F48F6BMALSylksk

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

